-- Set options for first time users
if (LINGUISTICS_FIRSTUSER == nil) then
	LINGUISTICS_MASTOG = true
	LINGUISTICS_OPTWOWLFR = true
	LINGUISTICS_OPTWOWZON = true
	LINGUISTICS_OPTWOWDUN = true
	LINGUISTICS_OPTWOWRAI = true
	LINGUISTICS_OPTWOWBAT = true
	LINGUISTICS_OPTINT = true
	LINGUISTICS_OPTNUM = true
	LINGUISTICS_OPTPUN = true
	LINGUISTICS_FIRSTUSER = true
	LINGUISTICS_CHAFIL = false
end

-- Create UI
local name = ...
do
	--[[ Slash Handler ]]--
	SlashCmdList["LINGUISTICS"] = function() InterfaceOptionsFrame_OpenToCategory(name) end
	SLASH_LINGUISTICS1 = "/linguistics"
	SLASH_LINGUISTICS2 = "/ling"

	--[[ Localization ]]--
	local locMasTog = "Master switch. Turn Linguistics on or off."
	local locMasTxt = "Thank you for making use of Linguistics. Currently\nthere is only English language support. If you notice\nany bugs, errors or words that are incorrectly changed\nthen please report this on |cff69ccf0curse.com|r. Now, talk like a sir."
	local locOptWowLfr = "Write out LF abbreviations."
	local locOptWowZon = "Write out zone abbreviations."
	local locOptWowDun = "Write out dungeon abbreviations."
	local locOptWowRai = "Write out raid abbreviations."
	local locOptWowBat = "Write out batteground abbreviations."
	local locOptInt = "Correct common misspelled words and internet slang."
	local locOptNum = "Write out numbers 1-9."
	local locOptPun = "Add missing and remove excessive punctuation."
	local locChaFil = "|cff69ccf0Apply the filters above to the chat from other people.|r"
	
	local locToDo = "- When linking items or spells all filters are ignored.\n\nAuthor: |cff00FF00Zedax (Outland-EU)|r\nWebsite: |cff69ccf0http://www.curse.com/addons/wow/linguistics|r"
	
	--[[ Main Panel ]]--
	local linguistics = CreateFrame("Frame", "LinguisticsConfig", InterfaceOptionsFramePanelContainer)
	--linguistics:SetScript("OnEvent", function(self, event, ...) self[event](self, event, ...) end)
	linguistics:Hide()
	linguistics.name = name
	linguistics:SetScript("OnShow", function()
	-- Check or uncheck boxes by loading from vars
		LinguisticsConfigMasterButton:SetChecked(LINGUISTICS_MASTOG)
		LinguisticsConfigOptionsWowLfr:SetChecked(LINGUISTICS_OPTWOWLFR)
		LinguisticsConfigOptionsWowZon:SetChecked(LINGUISTICS_OPTWOWZON)
		LinguisticsConfigOptionsWowDun:SetChecked(LINGUISTICS_OPTWOWDUN)
		LinguisticsConfigOptionsWowRai:SetChecked(LINGUISTICS_OPTWOWRAI)
		LinguisticsConfigOptionsWowBat:SetChecked(LINGUISTICS_OPTWOWBAT)
		LinguisticsConfigOptionsInt:SetChecked(LINGUISTICS_OPTINT)
		LinguisticsConfigOptionsNum:SetChecked(LINGUISTICS_OPTNUM)
		LinguisticsConfigOptionsPun:SetChecked(LINGUISTICS_OPTPUN)
		LinguisticsConfigChatFilter:SetChecked(LINGUISTICS_CHAFIL)
	-- Disable buttons if masterswich is off
		if ( LinguisticsConfigMasterButton:GetChecked() == nil ) then
			LinguisticsConfigOptionsWowLfr:Disable();
			LinguisticsConfigOptionsWowZon:Disable();
			LinguisticsConfigOptionsWowDun:Disable();
			LinguisticsConfigOptionsWowRai:Disable();
			LinguisticsConfigOptionsWowBat:Disable();
			LinguisticsConfigOptionsInt:Disable();
			LinguisticsConfigOptionsNum:Disable();
			LinguisticsConfigOptionsPun:Disable();
			LinguisticsConfigChatFilter:Disable();
		end
	end)
	local title = linguistics:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	title:SetPoint("TOPLEFT", 16, -16)
	title:SetText("Linguistics v2.0 |cff69ccf0[English]|r") --wowace magic, replaced with tag version
	InterfaceOptions_AddCategory(linguistics)

	--[[ Master Checkbox ]]--
	local btnMasTog = CreateFrame("CheckButton", "LinguisticsConfigMasterButton", linguistics, "OptionsBaseCheckButtonTemplate")
	btnMasTog:SetPoint("TOPLEFT", 16, -35)
	btnMasTog:SetScript("OnClick", function(frame)
		if frame:GetChecked() then
			PlaySound("igMainMenuOptionCheckBoxOn")
			LINGUISTICS_MASTOG = true
			LinguisticsConfigOptionsWowLfr:Enable();
			LinguisticsConfigOptionsWowZon:Enable();
			LinguisticsConfigOptionsWowDun:Enable();
			LinguisticsConfigOptionsWowRai:Enable();
			LinguisticsConfigOptionsWowBat:Enable();
			LinguisticsConfigOptionsInt:Enable();
			LinguisticsConfigOptionsNum:Enable();
			LinguisticsConfigOptionsPun:Enable();
			LinguisticsConfigChatFilter:Enable();
		else
			PlaySound("igMainMenuOptionCheckBoxOff")
			LINGUISTICS_MASTOG = nil
			LinguisticsConfigOptionsWowLfr:Disable();
			LinguisticsConfigOptionsWowZon:Disable();
			LinguisticsConfigOptionsWowDun:Disable();
			LinguisticsConfigOptionsWowRai:Disable();
			LinguisticsConfigOptionsWowBat:Disable();
			LinguisticsConfigOptionsInt:Disable();
			LinguisticsConfigOptionsNum:Disable();
			LinguisticsConfigOptionsPun:Disable();
			LinguisticsConfigChatFilter:Disable();
		end
	end)
	
	local btnMasTogText = btnMasTog:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	btnMasTogText:SetPoint("LEFT", btnMasTog, "RIGHT", 0, 0)
	btnMasTogText:SetText(locMasTog)
	local btnMasTogDesc = btnMasTog:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	btnMasTogDesc:SetPoint("TOPLEFT", btnMasTogText, "BOTTOMLEFT", 0, -5)
	btnMasTogDesc:SetJustifyH("LEFT")
	btnMasTogDesc:SetWordWrap(true)
	btnMasTogDesc:SetText(locMasTxt)

	--[[ Options Header ]]--
	local optionsTitle = linguistics:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	optionsTitle:SetPoint("TOPLEFT", btnMasTogDesc, "BOTTOMLEFT", 0, -10)
	optionsTitle:SetText("World of Warcraft filters")
	
	--[[ Options WoW LFR ]]--
	local btnOptWowLfr = CreateFrame("CheckButton", "LinguisticsConfigOptionsWowLfr", linguistics, "OptionsBaseCheckButtonTemplate")
	btnOptWowLfr:SetPoint("TOPLEFT", 43, -137)
	btnOptWowLfr:SetScript("OnClick", function(frame)
		if frame:GetChecked() then
			PlaySound("igMainMenuOptionCheckBoxOn")
			LINGUISTICS_OPTWOWLFR = true
		else
			PlaySound("igMainMenuOptionCheckBoxOff")
			LINGUISTICS_OPTWOWLFR = nil
		end
	end)
	
	local btnOptWowLfrText = btnOptWowLfr:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	btnOptWowLfrText:SetPoint("LEFT", btnOptWowLfr, "RIGHT", 0, 0)
	btnOptWowLfrText:SetText(locOptWowLfr)
	
	--[[ Options WoW ZON ]]--
	local btnOptWowZon = CreateFrame("CheckButton", "LinguisticsConfigOptionsWowZon", linguistics, "OptionsBaseCheckButtonTemplate")
	btnOptWowZon:SetPoint("TOPLEFT", 43, -157)
	btnOptWowZon:SetScript("OnClick", function(frame)
		if frame:GetChecked() then
			PlaySound("igMainMenuOptionCheckBoxOn")
			LINGUISTICS_OPTWOWZON = true
		else
			PlaySound("igMainMenuOptionCheckBoxOff")
			LINGUISTICS_OPTWOWZON = nil
		end
	end)
	
	local btnOptWowZonText = btnOptWowZon:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	btnOptWowZonText:SetPoint("LEFT", btnOptWowZon, "RIGHT", 0, 0)
	btnOptWowZonText:SetText(locOptWowZon)
	
	--[[ Options WoW DUN ]]--
	local btnOptWowDun = CreateFrame("CheckButton", "LinguisticsConfigOptionsWowDun", linguistics, "OptionsBaseCheckButtonTemplate")
	btnOptWowDun:SetPoint("TOPLEFT", 43, -177)
	btnOptWowDun:SetScript("OnClick", function(frame)
		if frame:GetChecked() then
			PlaySound("igMainMenuOptionCheckBoxOn")
			LINGUISTICS_OPTWOWDUN = true
		else
			PlaySound("igMainMenuOptionCheckBoxOff")
			LINGUISTICS_OPTWOWDUN = nil
		end
	end)
	
	local btnOptWowDunText = btnOptWowDun:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	btnOptWowDunText:SetPoint("LEFT", btnOptWowDun, "RIGHT", 0, 0)
	btnOptWowDunText:SetText(locOptWowDun)
	
	--[[ Options WoW RAI ]]--
	local btnOptWowRai = CreateFrame("CheckButton", "LinguisticsConfigOptionsWowRai", linguistics, "OptionsBaseCheckButtonTemplate")
	btnOptWowRai:SetPoint("TOPLEFT", 43, -197)
	btnOptWowRai:SetScript("OnClick", function(frame)
		if frame:GetChecked() then
			PlaySound("igMainMenuOptionCheckBoxOn")
			LINGUISTICS_OPTWOWRAI = true
		else
			PlaySound("igMainMenuOptionCheckBoxOff")
			LINGUISTICS_OPTWOWRAI = nil
		end
	end)
	
	local btnOptWowRaiText = btnOptWowRai:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	btnOptWowRaiText:SetPoint("LEFT", btnOptWowRai, "RIGHT", 0, 0)
	btnOptWowRaiText:SetText(locOptWowRai)
	
	--[[ Options WoW BAT ]]--
	local btnOptWowBat = CreateFrame("CheckButton", "LinguisticsConfigOptionsWowBat", linguistics, "OptionsBaseCheckButtonTemplate")
	btnOptWowBat:SetPoint("TOPLEFT", 43, -217)
	btnOptWowBat:SetScript("OnClick", function(frame)
		if frame:GetChecked() then
			PlaySound("igMainMenuOptionCheckBoxOn")
			LINGUISTICS_OPTWOWBAT = true
		else
			PlaySound("igMainMenuOptionCheckBoxOff")
			LINGUISTICS_OPTWOWBAT = nil
		end
	end)
	
	local btnOptWowBatText = btnOptWowBat:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	btnOptWowBatText:SetPoint("LEFT", btnOptWowBat, "RIGHT", 0, 0)
	btnOptWowBatText:SetText(locOptWowBat)

	--[[ Miscellaneous Header ]]--
	local optionsTitle = linguistics:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	optionsTitle:SetPoint("TOPLEFT", btnOptWowBat, "BOTTOMLEFT", 0, -5)
	optionsTitle:SetText("Miscellaneous filters")
	
	--[[ Options Internet Slang ]]--
	local btnOptInt = CreateFrame("CheckButton", "LinguisticsConfigOptionsInt", linguistics, "OptionsBaseCheckButtonTemplate")
	btnOptInt:SetPoint("TOPLEFT", 43, -267)
	btnOptInt:SetScript("OnClick", function(frame)
		if frame:GetChecked() then
			PlaySound("igMainMenuOptionCheckBoxOn")
			LINGUISTICS_OPTINT = true
		else
			PlaySound("igMainMenuOptionCheckBoxOff")
			LINGUISTICS_OPTINT = nil
		end
	end)
	
	local btnOptIntText = btnOptInt:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	btnOptIntText:SetPoint("LEFT", btnOptInt, "RIGHT", 0, 0)
	btnOptIntText:SetText(locOptInt)

		--[[ Options Numbers ]]--
	local btnOptNum = CreateFrame("CheckButton", "LinguisticsConfigOptionsNum", linguistics, "OptionsBaseCheckButtonTemplate")
	btnOptNum:SetPoint("TOPLEFT", 43, -287)
	btnOptNum:SetScript("OnClick", function(frame)
		if frame:GetChecked() then
			PlaySound("igMainMenuOptionCheckBoxOn")
			LINGUISTICS_OPTNUM = true
		else
			PlaySound("igMainMenuOptionCheckBoxOff")
			LINGUISTICS_OPTNUM = nil
		end
	end)
	
	local btnOptNumText = btnOptNum:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	btnOptNumText:SetPoint("LEFT", btnOptNum, "RIGHT", 0, 0)
	btnOptNumText:SetText(locOptNum)
	
	--[[ Options Punctuation ]]--
	local btnOptPun = CreateFrame("CheckButton", "LinguisticsConfigOptionsPun", linguistics, "OptionsBaseCheckButtonTemplate")
	btnOptPun:SetPoint("TOPLEFT", 43, -307)
	btnOptPun:SetScript("OnClick", function(frame)
		if frame:GetChecked() then
			PlaySound("igMainMenuOptionCheckBoxOn")
			LINGUISTICS_OPTPUN = true
		else
			PlaySound("igMainMenuOptionCheckBoxOff")
			LINGUISTICS_OPTPUN = nil
		end
	end)
	
	local btnOptPunText = btnOptPun:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	btnOptPunText:SetPoint("LEFT", btnOptPun, "RIGHT", 0, 0)
	btnOptPunText:SetText(locOptPun)

	--[[ Chat Filter ]]--
	local btnChaFil = CreateFrame("CheckButton", "LinguisticsConfigChatFilter", linguistics, "OptionsBaseCheckButtonTemplate")
	btnChaFil:SetPoint("TOPLEFT", 43, -340)
	btnChaFil:SetScript("OnClick", function(frame)
		if frame:GetChecked() then
			PlaySound("igMainMenuOptionCheckBoxOn")
			LINGUISTICS_CHAFIL = true
		else
			PlaySound("igMainMenuOptionCheckBoxOff")
			LINGUISTICS_CHAFIL = nil
		end
	end)
	
	local btnChaFilText = btnChaFil:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	btnChaFilText:SetPoint("LEFT", btnChaFil, "RIGHT", 0, 0)
	btnChaFilText:SetText(locChaFil)
	
	local ZZtexture = linguistics:CreateTexture(nil, "ARTWORK")
	ZZtexture:SetPoint("TOPLEFT", 360, 2)
	ZZtexture:SetTexture("Interface\\AddOns\\Linguistics\\lingsir.blp")

	local btnMasTogDesc = btnMasTog:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	btnMasTogDesc:SetPoint("TOPLEFT", btnOptPunText, "BOTTOMLEFT", -43, -5)
	btnMasTogDesc:SetJustifyH("LEFT")
	btnMasTogDesc:SetWordWrap(true)
	btnMasTogDesc:SetText("|cff69ccf0-----------------------------------------------------------------------------------------|r")

	local btnMasTogDesc = btnMasTog:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	btnMasTogDesc:SetPoint("TOPLEFT", btnChaFilText, "BOTTOMLEFT", -43, -4)
	btnMasTogDesc:SetJustifyH("LEFT")
	btnMasTogDesc:SetWordWrap(true)
	btnMasTogDesc:SetText("|cff69ccf0-----------------------------------------------------------------------------------------|r")
	
	--[[ To-do Header ]]--
	local todoTitle = linguistics:CreateFontString(nil, "ARTWORK", "GameFontRedLarge")
	todoTitle:SetPoint("TOPLEFT", btnOptPunText, "BOTTOMLEFT", -43, -51)
	todoTitle:SetText("Upcoming features and known bugs [Patch 5.0.5]")
	
	local btnMasTogDesc = btnMasTog:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	btnMasTogDesc:SetPoint("TOPLEFT", btnOptPunText, "BOTTOMLEFT", -43, -74)
	btnMasTogDesc:SetJustifyH("LEFT")
	btnMasTogDesc:SetWordWrap(true)
	btnMasTogDesc:SetText(locToDo)
end

